@@ -1,4 +1,4 @@
-from cgdb.recources.aggregation import Aggregation
+from cgdb.resources.aggregation import Aggregation
 
 
 class AggregationsManager:
