@@ -1,5 +1,5 @@
 from cgdb.utils.ManagerMix import ManagerMix
-from cgdb.recources.department import Department
+from cgdb.resources.department import Department
 
 
 class DepartmentsManager(ManagerMix):
