@@ -1,4 +1,4 @@
-from cgdb.recources.elementsCategory import ElementsCategory
+from cgdb.resources.elementsCategory import ElementsCategory
 from cgdb.utils.ManagerMix import ManagerMix
 
 
