@@ -40,3 +40,6 @@ class Site:
 
     def data_set_by_code(self, element, aggregation, time_step, level=None, elementMarkOverride = None):
         return self._client._data_sets_manager.data_set_by_code(self, element, aggregation, time_step, level, elementMarkOverride)
+
+    def delete_site(self):
+        self._client._sites_manager.delete_site(self)
