@@ -28,3 +28,13 @@ class ManagerMix:
                 raise EntityNotFoundException(content["code"], content["message"] + "\n Entity url: " + url)
 
         return raw_content
+
+    def delete(self, url=""):
+        raw_content = self._client._session.delete(url)
+        print(raw_content.status_code)
+        if raw_content.status_code != 200:
+            if raw_content.status_code == 404:
+                content = json.loads(raw_content.content)
+                raise EntityNotFoundException(content["code"], content["message"] + "\n Entity url: " + url)
+
+        return raw_content
